package ca.hivesolutions.BarcodeReader
import android.content.Context
import ca.hivesolutions.toughpad.ToughpadPlugin

import com.panasonic.toughpad.android.api.ToughpadApi
import com.panasonic.toughpad.android.api.ToughpadApiListener
import com.panasonic.toughpad.android.api.barcode.BarcodeData
import com.panasonic.toughpad.android.api.barcode.BarcodeListener
import com.panasonic.toughpad.android.api.barcode.BarcodeReader
import com.panasonic.toughpad.android.api.barcode.BarcodeReaderManager
import com.panasonic.toughpad.android.api.appbtn.AppButtonManager
import io.reactivex.subjects.BehaviorSubject

import android.content.ComponentName
import android.content.Intent

class BarcodeReaderSrv constructor(): ToughpadApiListener, BarcodeListener {
    var hasHardware = false
    var hasButtons = false
    private var initialized = false
    val barcode: BehaviorSubject<String> = BehaviorSubject.create()
    val hardware: BehaviorSubject<Boolean> = BehaviorSubject.create()
    val buttons: BehaviorSubject<Boolean> = BehaviorSubject.create()

    private lateinit var reader: BarcodeReader
    private lateinit var context: Context

    fun init(contextIn: Context) {
        
        if (!initialized) {
            initialized = true
            context = contextIn
            try {
                ToughpadApi.initialize(context, this)
                hasHardware = true
                hardware.onNext(true)
            } catch(e: Exception) {
                hasHardware = false
                hardware.onNext(false)
            }
            barcode.onNext("")
        }
    }

    fun reset() {
        barcode.onNext("")
    }

    fun startBarcodeScan() {
        reader.pressSoftwareTrigger(true)
    }

    fun stopBarcodeScan() {
        reader.pressSoftwareTrigger(false)
    }

    override fun onRead(bsObj: BarcodeReader, result: BarcodeData) {
        var barcodeStr: String = result.textData
        barcodeStr = barcodeStr.replace("\\n".toRegex(), "")
        barcodeStr = barcodeStr.replace("\\r".toRegex(), "")
        barcode.onNext(barcodeStr)
    }

    override fun onApiConnected(version: Int) {
        reader = BarcodeReaderManager.getBarcodeReaders()[0]
        reader.enable(10000)
        reader.addBarcodeListener(this)

    }

    override fun onApiDisconnected() {}
}
